#define OBJECTS_CC
#include "defs.hh"

#include "objects.hh"

// reserved: X, S, I, Y, 0-9

const struct ObjectDesc AsciiObjects[] =
{
  //  0
  { 'y', 0x0,0xC }, // bunby heri - the annoying thing in Cutman level beginning
  { 'm', 0x0,0x8 }, // metto
  { 'j', 0x8,0x8 }, // red jumping junk (Flea)
  { 'f', 0x8,0xC }, // floor trap (Spine/Gabyoall)
  //  4
  { 'c', 0x8,0x8 }, // vertically moving eyecube
  { 'v', 0x8,0x0 }, // spread cannon in floor
  { 0 },   // SPECIAL, SEE BELOW
  { 'i', 0x0,0x0 }, // sinewave flying penguin
  //  8
  { 's', 0xF,0x0 }, // sinewave flying bomb
  { 't', 0x0,0xC }, // jumping telephone post (Big Eye) (bomb damage only 4)
  { 'u', 0x8,0x0 }, // hamburger
  { '<', 0x8,0x8 }, // singleshot cannon pointing left (timing 1)
  //  C
  { '-', 0x0,0x8 }, // elec arc
  { 'B', 0x8,0x0 }, // periodical bombing (y = 0xE0) (not destroyable)
  { 0 },   // SPECIAL, SEE BELOW
  { 'I', 0x8,0x0 }, // flying fire, take two! (not destroyable)
  // 10
  { 0 },   // SPECIAL, SEE BELOW
  { 0 },
  { 'G', 0x0,0x4 }, // green guardian (Xl=0, Yl=4)
  { 'L', 0x0,0xC }, // shooting lift ("foot holder") (ont destroyable)
  // 14
  { 'R', 0x0,0x4 }, // robots that may lose their head
  { 'a', 0x0,0x4 }, // axe throwing robot in Gutsman
  { '.', 0x8,0x0 }, // spread cannon pointing down
  { '>', 0x8,0x8 }, // singleshot cannon pointing right
  // 18
  { ']', 0x4,0x6 }, // fire torch to the right (Fireman)
  { '', 0x0,0x7 }, // electricity decoration 1 (Elecman level only)
  { 0 }, // bullet sound? (not destroyable)
  { 0 }, //small explosion (from object $0D but also from enemy killed) (not destroyable)
  // 1C
  { 'r', 0x0,0x4 }, // scissor machine
  { 0 }, //instantiated at $B222, $BC73
  { 0 }, //instantiated at $BD1F
  { 0 }, //instantiated at $B752
  // 20
  { 0 },
  { 'h', 0x8,0x8 }, // horizontally moving eyecube
  { '{', 0x8,0x8 }, // singleshot cannon pointing left (timing 2)
  { '^', 0x8,0x8 }, // singleshot cannon pointing up
  // 24
  { '=', 0x0,0x8 }, // elec arc, different timing
  { '', 0x0,0x7 }, // electricity decoration 2 (Elecman level only)
  { 0 },
  { 0 }, // buzzblocks (Elecman stage)
  // 28
  { 0 }, //instantiated at $AF19
  { 0 }, //instantiated at $B218, $B762
  { 0 }, //instantiated at $AD6A
  { 0 },
  // 2C
  { 0 },   // SPECIAL, SEE BELOW
  { 0 }, //bullet sound? instantiated at $E7F8
  { 0 },
  { 0 },   // SPECIAL, SEE BELOW
  // 30
  { 0 },   // SPECIAL, SEE BELOW
  { 'd', 0x0,0x0 }, // periodically three fire devils from lava to sky
  { 0 },   // SPECIAL, SEE BELOW
  { 0 },  // scissor weapon
  // 34
  { 0 },  // ice weapon
  { 0 },  // bomb weapon
  { 0 },  // fire weapon
  { 0 },  // fire shield weapon
  // 38
  { 0 },
  { 0 },
  { 0 },   // wily3 boss
  { 'T', 0x4,0xC }, // teleport when a "boss" killed, activate enemy if not dead.
  // 3C
  { 'o', 0x8,0x9 }, // score ball = bonus pearl
  { 'p', 0x8,0xC }, // small weapon
  { 'e', 0x8,0x9 }, // small energy
  { 'P', 0x8,0x8 }, // big weapon
  // 40 
  { 'E', 0x8,0x8 }, // big energy
  { 'U', 0x8,0x8 }, // 1up
  { 'M', 0x8,0x8 }, // magnet beam
  { 'O', 0x8,0x0 }, // teleport immediately (invisible)
  // 44
  { '*', 0x8,0x8 }, // end level
  { 'W', 0x8,0x8 }, // all weapons full (yashichi)
  { 0 },
  { 0 },
  // 48
  { 0 },
  { '', 0x8,0x8 }, // random powerup (enemy destruction)
  { 0 }, //? used at 0001CB5B
};

/*
     Controllers:
     
     0x06 functions:
             10,FF = this room has "watchers" (The flying beamers in Elecman and Wily4)
     0x0E functions:
             D0,04 = falling fire (Fireman level)
             B0,FF = zigzag fire (Fireman level)
     0x10 functions:
             E0,80 = activate buzzblocks (Iceman) - used twice
             10,80 = activate buzzblocks (Elecman)
     0x2C functions:
             10,FF = unknown (Wily4, screen 2) - also instantiated by 0001DA9A
     0x2F functions:
             80,80 = super scrolling start (Wily3)
             FC,80 = unknown (Gutsman, screen 1)
             58,80 = unknown (Gutsman, screen 4)
     0x30 functions:
             80,80 = super scrolling stop (Wily3)
             F8,80 = launch lift (Gutsman, screen 0)
             80,FF = stop lift (Gutsman, screen 0)
             60,80 = unknown (Gutsman, screen 5)
     0x32 functions:
             80,E0 = lava activator (Fireman) (??)
     0xFF functions:
             E0,0C = increase pace (wily3)
             01,08 = unknown (Gutsman, screen 5)
             40,0A = unknown (Gutsman, screen 5)
             10,04 = unknown (Gutsman, screen 6)
             50,06 = unknown (Gutsman, screen 6)
             80,02 = water start (Iceman)
             00,00 = water end   (Iceman)
 */

const unsigned NumAsciiObjects = sizeof(AsciiObjects) / sizeof(*AsciiObjects);
